 function COGv = com1mas(COP,freq,m,H)
% function COGv = com1mas(COP,freq,m,H)
% estimates COGv from COP using a FFT filter
% code from "Control of equilibrium in humnans: sway over sway", Duarte etal., 
% Motor Control 2010
% COGv(omega)/COP(omega) = omega_v^2 / (omega^2+omega_v^2)
% SYNTAX:
% COGv = cogve(COP,freq,m,H)
% cogve(COP,freq,m,H)
% INPUTS:
% COP: column vector of the center of pressure [m]
% freq: sampling frequency [Hz]
% m: body mass of the subject [kg]
% H: height of the subject [m]
% OUTPUT:
% COGv: column vector of the center of gravity vertical projection [m]
% cogve(COP,freq,m,H) with no output plots the COP and COGv data.

%Remove mean to decrease instabilities at the extremities:
mcop = mean(COP); COP = COP - mcop;

%Parameters:
%Height of the COG w.r.t. ankle:
%H = wzrost
%h = wysoko rodka cikoci
h = 0.56* H - 0.039*H;   %(McGinnis 2005 ; Winter 2005 )

% Body moment of inertia around the ankle:
% moment bezwadnoci ciaa wzgldem kostek) I=m*r^2
I = m*0.0533*H^2 + m*h^2;    %(Breniere 1996)

% Gravity acceleration:
g = 9.81;

% Pendulum natural frequency:
w02 = m*g*h/I;

%Make sure COP is a column vector:
if size(COP,1)==1; COP=COP'; disp('COP transformed to column vector'), end;

% Number of data:
ncop = length(COP);
nfft = 2^nextpow2(ncop);

% COP fft:
COPf = fft(COP,nfft)/ncop;

% Angular frequency vector:
w = 2*pi*freq/2*linspace(0,1,nfft/2+1)';
w = [w; -w(end-1:-1:2)];

%Transfer function:
TF = w02./(w.^2+w02);

%COGv:
COGv = real(ifft(COPf.*TF)*ncop);
COGv = COGv(1:ncop);

%Get back the mean (COP & COGv have same mean):
COP = COP+mcop; COGv = COGv+mcop;


%Plot:
t = (1:ncop)'/freq;
%figure, plot(t,COP,'b',t,COGv,'r','LineWidth',2);
%legend('COP','COGv','Location','best');
%xlabel('Time [s]'), ylabel('Amplitude [m]');

